@@ -65,9 +65,6 @@ int main(int argc, char* argv[])
     QApplication qa(argc, argv);
     qa.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     KLocalizedString::setApplicationDomain("drkonqi5");
-    QCoreApplication::setApplicationName(QStringLiteral("drkonqi"));
-    QCoreApplication::setApplicationVersion(QString::fromLatin1(version));
-    QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
     // Prevent KApplication from setting the crash handler. We will set it later...
     setenv("KDE_DEBUG", "true", 1);
@@ -86,8 +83,8 @@ int main(int argc, char* argv[])
                          QStringLiteral("gkiagia@users.sourceforge.net"));
     aboutData.addAuthor(i18nc("@info:credit","A. L. Spehr"), QString(),
                          QStringLiteral("spehr@kde.org"));
+    KAboutData::setApplicationData(aboutData);
     qa.setWindowIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug"), qa.windowIcon()));
-    qa.setDesktopFileName(QStringLiteral("org.kde.drkonqi"));
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
